@@ -3,8 +3,8 @@ import os
 from sys import version_info
 MAJOR=3
 MINOR=0
-PATCH=0
-VERSION="{MAJOR}.{MINOR}.{PATCH}".format(MAJOR=MAJOR, MINOR=MINOR, PATCH=PATCH)
+PATCH=1
+VERSION="{MAJOR}.{MINOR}.{PATCH}-2".format(MAJOR=MAJOR, MINOR=MINOR, PATCH=PATCH)
 
 BRANCH="master"
 COMMIT=None
@@ -21,7 +21,8 @@ def get_more_info():
     try:
         os.chdir(source_dir)
         response = mod_string(
-                subprocess.check_output(["git", "describe", "--long"])).strip()
+                subprocess.check_output(["git", "describe", "--long"], 
+                                         stderr=subprocess.STDOUT)).strip()
         tag, ahead, commit = response.split("-")
         AHEAD = ahead
         COMMIT = commit
