@@ -16,6 +16,7 @@ import pprint
 import re
 import strictyaml
 import subprocess
+import shlex
 import sys
 import yaml
 
@@ -440,7 +441,7 @@ def get_parser(version_string="Version: {vers} "
                         help="Annotation of genes in the consensus output sequence."
                              " Annotion file needs to be supplied in Gff format", 
                         type=realpathify(validate_gff_ext)) 
-    parser.add_argument("--pangolin", "-P", type=check_if_directory,
+    parser.add_argument("--pangolin", "-P", type=get_pangolin_location,
                         help="Pangolin environment location."
                              "If provided, it runs pangolin from the environment"
                              )
@@ -645,6 +646,88 @@ def realpathify(func):
         return os.path.realpath(func(*args, **kwargs))
     return realpathed_fun
 
+
+def get_pangolin_location(pangolin):
+    ranking_locations = [
+            os.getenv("SNAKE_CONDA_PREFIX", 
+                      default=DEFAULT_DATA_DIR),
+            DEFAULT_DATA_DIR,
+            "."]
+    has_pangolin = False
+    is_conda, prefix, has_pangolin = check_pangolin(pangolin, "pangolin")
+    if is_conda and not has_pangolin:
+        raise ValueError("Error with Pangolin Environment!:\n"
+                         " Pangolin Not Found in Environment\n"
+                         "Prefix: {prefix}\n"
+                         "".format(prefix=prefix))
+    if not is_conda:
+        for location in ranking_locations:
+            is_conda, prefix, has_pangolin = check_pangolin(
+                    os.path.join(location, pangolin), "pangolin")  
+            if is_conda and not has_pangolin:
+                raise ValueError("Error with Pangolin Environment!:\n"
+                                 " Pangolin Not Found in Environment\n"
+                                 "Prefix: {prefix}\n"
+                                 "".format(prefix=prefix))
+            if has_pangolin:
+                break
+    if not is_conda:
+        is_conda, prefix, has_pangolin = check_pangolin(None, pangolin)
+        if is_conda and not has_pangolin:
+            raise ValueError("Error with Pangolin Environment!:\n"
+                             " Pangolin Not Found in Environment\n"
+                             "Prefix: {prefix}\n"
+                             "".format(prefix=prefix))
+    if not is_conda:
+        raise ValueError("No valid pangolin environment found!\n"
+                         "input: {_input}\n"
+                         "".format(_input=pangolin))
+    return prefix
+
+
+    
+
+def check_pangolin(prefix, name):
+    is_conda = False
+    parsed_prefix = None
+    found_pangolin = False
+    prefix = prefix_augment(prefix) 
+    try:
+        call = ["conda", "list"] 
+        if prefix is None:
+            call.extend(["-n", shlex.quote(name)])
+        else:
+            call.extend(["--prefix", shlex.quote(prefix)])
+        env_list = subprocess.check_output(
+                """eval "$(conda shell.bash hook)"; {call}""".format(
+                    call=" ".join(call)),
+                shell=True,
+                stderr=subprocess.STDOUT, 
+                universal_newlines=True)
+        is_conda = True
+        env_list_lines = env_list.split("\n")
+        found_pangolin = any("pangolin" in line for line in env_list_lines[3:])
+        try:
+            parsed_prefix = prefix_augment(
+                    re.match('.*in environment at (.+):[\s]*$', 
+                             env_list_lines[0]).group(1))
+        except AttributeError as e:
+            pass
+    except subprocess.CalledProcessError:
+        pass
+    except FileNotFoundError:
+        pass
+    return is_conda, parsed_prefix, found_pangolin
+
+
+def prefix_augment(prefix):
+    if prefix is None:
+        return None
+    if not prefix.endswith('/'):
+        prefix = prefix + "/" 
+    return prefix
+
+
 def setup_log_dir(args):
     outdir = args.output
     if args.log is None:
@@ -1044,7 +1127,7 @@ def augment_config_with_args(args, config):
         config["pangolin"] = args.pangolin
     else:
         try:
-            config["pangolin"] = check_if_directory(str(config["pangolin"]))
+            config["pangolin"] = get_pangolin_location(str(config["pangolin"]))
             logger.info("Using pangolin environment")
         except ValueError as e:
             logger.warning("Fallback pangolin environment from config not used."
@@ -1182,9 +1265,11 @@ def check_and_add_fastq(_files, res, pdir, sample_names=None, alt_ids=None):
                              for a in sorted(ambig_keys))
             nonambig = sep.join(match_dict[na]
                                 for na in sorted(match_dict.keys())
-                                if na not in ambig_keys + ["read"])
+                                if na not in ambig_keys + ["read"] 
+                                and match_dict[na] is not None)
             sub_sample_id = sep.join(
-                    [val for (_id, val) in list(match.groupdict().items())
+                    [val if val is not None else ""  
+                     for (_id, val) in list(match.groupdict().items())
                      if _id not in ["read"]])
             if pattern.startswith("illumina_some_institute"):
                 matchdict = match.groupdict()
